@@ -1,6 +1,6 @@
 ###              Classes of correlation structures
 ###
-### Copyright 2005-2020  The R Core team
+### Copyright 2005-2024  The R Core team
 ### Copyright 1997-2003  Jose C. Pinheiro,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
 
@@ -201,7 +201,7 @@ getCovariate.corStruct <-
       if (is.null(grps)) {
         covar <- 1:nrow(data)
       } else {
-	covar <- lapply(split(grps, grps), function(x) seq_along(x))
+	covar <- lapply(split(grps, grps), seq_along)
       }
     }
     if (!is.null(grps)) {
@@ -771,7 +771,7 @@ summary.corNatural <-
   object
 }
 
-###*# corIdent - independent structure
+###*# corIdent - independent structure === DEPRECATED
 
 ####* Constructor
 
@@ -779,6 +779,12 @@ corIdent <-
   ## Constructor for the corIdent class
   function(form = NULL)
 {
+  .Deprecated(
+    msg = paste0(
+      "The \"corIdent\" class is deprecated.\n",
+      "Use argument 'correlation = NULL' for uncorrelated errors in model functions."
+    ),
+    package = "nlme")
   value <- numeric(0)
   attr(value, "formula") <- form
   attr(value, "fixed") <- TRUE
@@ -791,6 +797,7 @@ corIdent <-
 corMatrix.corIdent <-
   function(object, covariate = getCovariate(object), corr, ...)
 {
+  .Deprecated(package="nlme", old = "corMatrix.corIdent(): \"corIdent\" class")
   if(is.list(covariate)) {# by group
     as.list(lapply(covariate, function(el, object) corMatrix(object, el)))
   } else {
@@ -808,6 +815,7 @@ coef.corIdent <-
 Initialize.corIdent <-
   function(object, data, ...)
 {
+  .Deprecated(package="nlme", old = "Initialize.corIdent(): \"corIdent\" class")
   attr(object, "logDet") <- 0
   object
 }
@@ -819,6 +827,7 @@ recalc.corIdent <- function(object, conLin, ...) conLin
 summary.corIdent <-
   function(object, structName = "Independent", ...)
 {
+  .Deprecated(package="nlme", old = "summary.corIdent(): \"corIdent\" class")
   summary.corStruct(object, structName)
 }
 
@@ -1150,7 +1159,7 @@ corARMA <-
     stop("moving average order must be a non-negative integer")
   }
   if (0 == (p + q)) {
-    return(corIdent())
+    stop("at least one of 'p' and 'q' must be > 0")
   }
   if (length(value) != p + q) {
     stop("initial value for parameter of wrong length")
@@ -1746,6 +1755,7 @@ corFactor.corSpatial <- function(object, ...)
 corMatrix.corSpatial <-
   function(object, covariate = getCovariate(object), corr = TRUE, ...)
 {
+  ## the default 'covariate' excludes 1-obs groups (empty distance)
   nRt <- function(vec) round((1 + sqrt(1 + 8 * length(vec))) / 2)
   corD <- Dim(object,
 	      if(is.list(covariate)) {
